"use strict";
Object.defineProperty(exports, "default", {
    enumerable: true,
    get: ()=>_default
});
const _devkit = require("@nrwl/devkit");
const _exec = require("@actions/exec");
const _pluginConfig = require("../../utils/plugin-config");
const _fileutils = require("nx/src/utils/fileutils");
const _linkVercelProject = require("../../utils/linkVercelProject");
const path = require("path");
const fs = require("fs/promises");
async function copyEnvironmentFile(resolvedProjectPath, options) {
    if (!options.outputEnvFile) {
        throw new Error(`Can't create environment file, since outputEnvFile is not defined.`);
    }
    const downloadedEnvFile = path.resolve(resolvedProjectPath, `.vercel/.env.${options.environment}.local`);
    const outputEnvFile = path.resolve(resolvedProjectPath, options.outputEnvFile);
    if (!(0, _fileutils.fileExists)(downloadedEnvFile)) {
        throw new Error(`Expected file does not exist: ${downloadedEnvFile}, did the Vercel CLI command fail?`);
    }
    try {
        await fs.unlink(outputEnvFile);
        _devkit.logger.debug(`Deleted existing environment file: ${outputEnvFile}`);
    } catch (e) {
    // assuming deletion failed due to the file missing
    }
    await fs.cp(downloadedEnvFile, outputEnvFile);
    _devkit.logger.info(`Copied environment file from ${outputEnvFile} to ${downloadedEnvFile}`);
}
const runExecutor = async (options, context)=>{
    const { vercelCommand ='vercel'  } = (0, _pluginConfig.getPluginConfig)(context);
    if (!context.projectName) {
        throw new Error('nx-vercel requires projectName to be assigned');
    }
    const projectPath = path.resolve(context.root, context.workspace.projects[context.projectName].root);
    const pullArgs = [
        'pull',
        '--cwd',
        projectPath,
        '--environment',
        options.environment, 
    ];
    if (options.debug) {
        pullArgs.push('--debug');
    }
    if (process.env.VERCEL_TOKEN) {
        _devkit.logger.debug('Detected VERCEL_TOKEN, passing token to Vercel CLI');
        pullArgs.push('--token', process.env.VERCEL_TOKEN);
    }
    // apparently we can set VERCEL_ORG_ID and VERCEL_PROJECT_ID instead
    (0, _linkVercelProject.linkVercelProject)(projectPath, {
        projectId: options.projectId,
        orgId: options.orgId
    });
    await (0, _exec.exec)(vercelCommand, pullArgs, {
        cwd: context.root
    });
    if (options.outputEnvFile) {
        await copyEnvironmentFile(projectPath, options);
    }
    return {
        success: true
    };
};
const _default = runExecutor;

//# sourceMappingURL=executor.js.map