import { Executor, ExecutorContext, Target } from '@nrwl/devkit';
import type { JsonObject } from 'type-fest';
export declare type TargetString = string;
export declare type TargetWithOptions = {
    target: Target | TargetString;
    overrides?: JsonObject;
};
export declare type PostTargets = (Target | TargetString | TargetWithOptions)[];
export declare function runPostTargets(targets: PostTargets, context: ExecutorContext, result: ExecutorResult): Promise<void>;
declare type NormalizedTargetWithOptions = TargetWithOptions & {
    target: Target;
};
export declare function normalizePostTargets(targets: (string | Target | TargetWithOptions)[]): NormalizedTargetWithOptions[];
export declare type ExecutorResult = {
    success: boolean;
    metadata?: JsonObject;
    env?: {
        [key: string]: string | number | boolean | null | undefined;
    };
};
export declare type PostTargetsOptions = {
    /**
     * Executor targets to run after this task has completed or failed.
     *
     * The target overrides are enhanced with support for environment variable
     * placeholders. Use `$ENV_VAR_NAME` in any string key or value and it will be
     * replaced with the value of the environment variable.
     */
    postTargets?: {
        onSuccess?: PostTargets;
        onFailure?: PostTargets;
    };
};
export declare type ExecutorWithPostTargets<Options extends PostTargetsOptions = any> = (options: Options, context: ExecutorContext) => Promise<ExecutorResult> | AsyncIterableIterator<ExecutorResult>;
export declare function withPostTargets<Options extends PostTargetsOptions>(executor: ExecutorWithPostTargets<Options>): Executor<Options>;
export {};
